#!/usr/bin/env python

import unittest
import ephem

# Determine whether angles work reasonably.

class ConstantTests(unittest.TestCase):
    def test_constants(self):
        self.assertEqual(ephem.c, 299792458)
        self.assertEqual(ephem.meters_per_au, 1.4959787e11)
        self.assertEqual(ephem.earth_radius, 6378160)
        self.assertEqual(ephem.moon_radius, 1740000)
        self.assertEqual(ephem.sun_radius, 695000000)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
import ephem

# See whether asking for the rising-time of Mars hangs indefinitely.

class Launchpad236872Tests(unittest.TestCase):
    def runTest(self):
        mars = ephem.Mars()
        boston = ephem.city('Boston')
        boston.date = ephem.Date('2008/5/29 15:59:16')
        boston.next_rising(mars)
